# index-hr
[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.svg?v=103)](https://github.com/ellerbrock/open-source-badges/)
[![license](https://img.shields.io/github/license/marinko-peso/index-hr.svg)](https://github.com/marinko-peso/gremlinc/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/indexhr.svg)](https://pypi.org/project/indexhr/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/indexhr.svg)](https://pypi.org/project/indexhr/)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg)](http://makeapullrequest.com)

index.hr basic news content in the terminal


# Installation

Available on PyPi, latest version 0.5.
Compatible with Python 2.7.x and 3.5.x.

```sh
pip install indexhr
```


# Usage

In terminal as ```index-hr```.
Navigation using up/down arrows. Clicking enter will open the selected in the new tab of your browser.


# Example

![Content Example](example.png)


# License

MIT.
